@@ -3,7 +3,7 @@
 *                    F i n d   P a t t e r n   I n   F i l e s                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -161,7 +161,7 @@ public:
   FXbool continueProcessing();
 
   /// Called by visitor to deposit new search result
-  void appendSearchResult(const FXString& relpath,const FXString& text,FXint lineno,FXint column);
+  void appendSearchResult(const FXString& relpath,const FXString& hit,FXint lineno,FXint column);
 
   /// Clear search results
   void clearSearchResults();
