@@ -1,4 +1,4 @@
-/*********** Generated on 2024/08/15 23:38:05 by reswrap version 6.0.0 *********/
+/*********** Generated on 2025/12/31 09:55:20 by reswrap version 6.0.0 *********/
 
 #include "help.h"
 
@@ -400,35 +400,41 @@ const char help[]=
   "The editor supports unlimited (well, the limit is large...) undo and redo capabi"
   "lity.  Each time you insert, remove, or replace some text, the editor remembers "
   "what you did.\n"
-  "If you make a mistake, you can undo the last command, and the one before that, a"
-  "nd so on. Having invoked undo many times, it is sometimes desirable to invoke th"
-  "e redo command, i.e. to perform the original editing operation again.  Thus, you"
-  " can move backward or forward in time.\n"
+  "If you make a mistake, you can undo the last edit, and the one before that, and "
+  "so on. Having invoked undo many times, it is sometimes desirable to invoke the r"
+  "edo command, i.e. to perform the original editing operation again.  Thus, you ca"
+  "n move backward or forward in time.\n"
+  "\n"
   "The \"Merge Undos\" option consolidates contiguous single-character insertions o"
   "r deletions into larger undo commands.  When the \"Merge Undos\" mode is on, an "
-  "undo or redo will undo inserts or deletes on a word-by-word bases.  It tries to "
+  "undo or redo will undo inserts or deletes on a word-by-word basis.  It tries to "
   "be smart about which character classes are \"mergeable,\" so that for example ed"
   "iting source code, we're not backing over operators and other punctuation that m"
   "ay have special meanings in programming languages (we're still experimenting wit"
   "h this feature so the precise behaviour will be fine-tuned a bit in the future.\n"
+  "\n"
   "A new addition to the undo system is the \"Alternate History\" mode.  If, after "
   "undoing several commands, you decide edit the buffer in a different way, all com"
-  "mands that you have undone will be deleted, and you will no longer be able to go"
-  " forward with redo at that point.\n"
+  "mands that you have undone would normally be deleted, and you would no longer be"
+  " able to go forward with redo from that point.\n"
   "However, when \"Alternate History\" mode on, Adie will remember \"the path not t"
   "aken\" and allow you to undo back to the original text, prior to the change.\n"
+  "\n"
   "Needless to say, this may vastly expand the amount of memory used by the undo sy"
   "stem; however, to prevent things getting out of hand the undo list is periodical"
   "ly trimmed to keep it manageable.\n"
+  "\n"
   "When you load a file, or save a file after editing it, the undo system will reme"
   "mber the state of the text buffer as \"clean\" or \"marked\".  Making further ch"
   "anges, you will be able to quickly go back to this clean state using the \"Rever"
   "t\" command.  Unlike reload, no disk I/O is performed when this happens: we're s"
   "imply exucuting undo or redo commands to go back to the marked state.\n"
+  "\n"
   "Of course, if a huge amount of text was modified, and the undo list had to be tr"
   "immed, you will potentially not be able to reach the marked state anymore if it "
-  "wanders into the trimmed range.  However, the limits are set pretty large for ed"
-  "iting regular source files.\n"
+  "wanders into the trimmed range.  However, the default limits are set pretty larg"
+  "e for editing regular source files; if you ever run into these limits, they can "
+  "be changed in the preferences panel.\n"
   "\n"
   "\n"
   "Evaluating Numerical Expressions.\n"
@@ -461,10 +467,10 @@ const char help[]=
   "  ( )\tparenthesized subexpressions\n"
   "\n"
   "The expression calculator knows common math functions: abs(), acos(), acosh(), a"
-  "sin(), asinh(), atan(), atanh(), cbrt(), ceil(), cos(), cosh(), cub(), erf(), er"
-  "fc(), exp(), exp2(), exp10(), floor(), inverf(), inverfc(), isfin(), isinf(), is"
-  "nan(), log(), log2(), log10(), near(), round(), sin(), sinh(), sqr(), sqrt(), ta"
-  "n(), tanh(), trunc(), wrap(), wrap4(), max(), min(), atan2().\n"
+  "sin(), asinh(), atan(), atan2(), atanh(), cbrt(), ceil(), cos(), cosh(), cub(), "
+  "erf(), erfc(), exp(), exp2(), exp10(), floor(), inverf(), inverfc(), isfin(), is"
+  "inf(), isnan(), log(), log2(), log10(), max(), min(), near(), pow(), round(), si"
+  "n(), sinh(), sqr(), sqrt(), tan(), tanh(), trunc(), wrap(), wrap4().\n"
   "\n"
   "And a few mathematical constants: PI, E, DTOR (degree to radians), RTOD (radians"
   " to degrees).\n"
@@ -1150,7 +1156,7 @@ const char help[]=
   "When Adie starts up, it normally looks in the directories listed in the PATH env"
   "ironment variable.  There are installations where this is not convenient.  There"
   "fore, it is possible to set the search directories using the special 'syntaxpath"
-  "s' registry setting.\n"
+  "' registry setting.\n"
   "For testing purposes, you can also pass the filename of the syntax file directly"
   " on the command line using '-S' or '--syntax' flag.\n"
   "\n"
