@@ -3,7 +3,7 @@
 *                            D a t e   C l a s s                                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -71,6 +71,12 @@ public:
   /// Get julian day number
   FXuint getJulian() const { return julian; }
 
+  /// Set date to 1st day of year 
+  void setDate(FXint yr);
+
+  /// Get year from date
+  void getDate(FXint& yr) const;
+
   /// Set date to year and day of year
   void setDate(FXint yr,FXint dy);
 
