@@ -3,7 +3,7 @@
 *                   F i l e   S e l e c t i o n   D i a l o g                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -179,6 +179,12 @@ public:
   /// Return File List style
   FXuint getFileBoxStyle() const;
 
+  /// Change File List sorting order
+  void setSortOrder(FXuint order);
+
+  /// Return File List sorting order
+  FXuint getSortOrder() const;
+
   /// Allow or disallow navigation
   void allowNavigation(FXbool flag);
 
