@@ -3,7 +3,7 @@
 *           D o u b l e - P r e c i s i o n    S p h e r e    C l a s s         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -50,6 +50,9 @@ public:
   /// Initialize sphere to fully contain the given bounding box
   FXSphered(const FXRanged& bounds);
 
+  /// Assign with vector
+  FXSphered& operator=(const FXVec3d& cen){ center=cen; radius=0.0; return *this; }
+
   /// Assignment
   FXSphered& operator=(const FXSphered& sphere){ center=sphere.center; radius=sphere.radius; return *this; }
 
