@@ -3,7 +3,7 @@
 *                         C o l o r R i n g   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -42,7 +42,6 @@
 #include "FXColorRing.h"
 
 
-
 /*
 
   Notes:
@@ -110,10 +109,8 @@
 
 #define JUSTIFY_MASK  (JUSTIFY_HZ_APART|JUSTIFY_VT_APART)
 
-
 using namespace FX;
 
-
 /*******************************************************************************/
 
 namespace FX {
@@ -301,7 +298,7 @@ void FXColorRing::updatering(){
 
           // Compute color
           fxhsv_to_rgb(r,g,b,Math::atan2((FXfloat)ry,(FXfloat)rx)*rtod+180.0f,1.0f,1.0f);
-          dial->setPixel(x,y,FXRGB(255.0f*r,255.0f*g,255.0f*b));
+          dial->setPixel(x,y,FXRGB(Math::lrint(255.0f*r),Math::lrint(255.0f*g),Math::lrint(255.0f*b)));
           continue;
           }
 
@@ -314,7 +311,7 @@ void FXColorRing::updatering(){
 
           // Compute color
           fxhsv_to_rgb(r,g,b,hsv[0],s,v);
-          dial->setPixel(x,y,FXRGB(255.0f*r,255.0f*g,255.0f*b));
+          dial->setPixel(x,y,FXRGB(Math::lrint(255.0f*r),Math::lrint(255.0f*g),Math::lrint(255.0f*b)));
           continue;
           }
         }
@@ -586,6 +583,7 @@ long FXColorRing::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 long FXColorRing::onMouseWheel(FXObject*,FXSelector,void* ptr){
   FXfloat amount=((FXEvent*)ptr)->code/12.0f;
   if(isEnabled()){
+    if(target && target->tryHandle(this,FXSEL(SEL_MOUSEWHEEL,message),ptr)) return 1;
     if(((FXEvent*)ptr)->state&CONTROLMASK) amount/=10.0f;
     setHue(Math::fmod(hsv[0]+amount+360.0f,360.0f));
     if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)hsv);
