@@ -3,7 +3,7 @@
 *                         D o c k   S i t e   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -60,6 +60,10 @@
     extra galleys, except when unavoidable.
 */
 
+#define TOPIC_CONSTRUCT 1000
+#define TOPIC_CREATION  1001
+#define TOPIC_DETAIL    1002
+
 #define FUDGE 20        // Amount to move down/up before jumping into next galley
 
 using namespace FX;
@@ -783,7 +787,7 @@ void FXDockSite::resizeToolBar(FXDockBar* bar,FXint barx,FXint bary,FXint barw,F
     FXint top,bottom,left,right,expand,require,w,h,mbw,mbh,t;
     FXWindow *begin,*end,*c;
 
-    //FXTRACE((100,"barx=%d bary=%d barw=%d barh=%d\n",barx,bary,barw,barh));
+    //FXTRACE((TOPIC_DETAIL,"barx=%d bary=%d barw=%d barh=%d\n",barx,bary,barw,barh));
 
     // Interior
     top=border+padtop;
