@@ -3,7 +3,7 @@
 *                        L i s t   B o x   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -67,7 +67,6 @@
 
 using namespace FX;
 
-
 /*******************************************************************************/
 
 namespace FX {
@@ -287,8 +286,10 @@ long FXListBox::onFocusDown(FXObject*,FXSelector,void*){
 // Mouse wheel
 long FXListBox::onMouseWheel(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
+  FXint index;
   if(isEnabled()){
-    FXint index=getCurrentItem();
+    if(target && target->tryHandle(this,FXSEL(SEL_MOUSEWHEEL,message),ptr)) return 1;
+    index=getCurrentItem();
     if(event->code<0){
       if(index<0) index=0;
       else if(index<getNumItems()-1) index++;
