@@ -3,7 +3,7 @@
 *                       M e n u   C a s c a d e   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -47,9 +47,12 @@
 
 /*
   Notes:
-  - Accelerators.
-  - Help text from constructor is third part; second part should be
-    accelerator key combination.
+  - Parse hotkey from label 1st part of the text, and strip the "&" from it.
+  - Parse help text from 3rd part of the text.
+  - The 2nd part of the text would have the accelerator.  But we don't need
+    that here.
+  - While typically not showing a tool tip, you can still set this by calling
+    setTipText() directly.
   - When menu label changes, hotkey might have to be adjusted.
   - Fix it so menu stays up when after Alt-F, you press Alt-E.
   - MenuItems should be derived from FXLabel.
@@ -57,6 +60,8 @@
   - Look into SEL_FOCUS_SELF some more...
 */
 
+#define TOPIC_CONSTRUCT 1000
+#define TOPIC_DETAIL    1001
 #define TOPIC_KEYBOARD  1009
 
 #define LEADSPACE   22
@@ -208,7 +213,7 @@ long FXMenuCascade::onKeyRelease(FXObject*,FXSelector sel,void* ptr){
 
 // Hot key combination pressed
 long FXMenuCascade::onHotKeyPress(FXObject*,FXSelector,void* ptr){
-  FXTRACE((200,"%s::onHotKeyPress %p\n",getClassName(),this));
+  FXTRACE((TOPIC_KEYBOARD,"%s::onHotKeyPress %p\n",getClassName(),this));
   handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr);
   if(isEnabled()){
     handle(this,FXSEL(SEL_COMMAND,ID_POST),nullptr);
@@ -219,7 +224,7 @@ long FXMenuCascade::onHotKeyPress(FXObject*,FXSelector,void* ptr){
 
 // Hot key combination released
 long FXMenuCascade::onHotKeyRelease(FXObject*,FXSelector,void*){
-  FXTRACE((200,"%s::onHotKeyRelease %p\n",getClassName(),this));
+  FXTRACE((TOPIC_KEYBOARD,"%s::onHotKeyRelease %p\n",getClassName(),this));
   return 1;
   }
 
