@@ -3,7 +3,7 @@
 *                       R e a l S l i d e r   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -42,9 +42,6 @@
 #include "FXApp.h"
 #include "FXRealSlider.h"
 
-
-
-
 /*
   Notes:
   - Maybe add bindings for arrow keys for value changes.
@@ -549,14 +546,19 @@ long FXRealSlider::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
 // Mouse wheel
 long FXRealSlider::onMouseWheel(FXObject*,FXSelector,void* ptr){
   FXEvent *event=(FXEvent*)ptr;
-  FXdouble p=pos+incr*(event->code/120);
-  if(p<range[0]) p=range[0];
-  if(p>range[1]) p=range[1];
-  if(pos!=p){
-    setValue(p);
-    if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+  FXdouble p;
+  if(isEnabled()){
+    if(target && target->tryHandle(this,FXSEL(SEL_MOUSEWHEEL,message),ptr)) return 1;
+    p=pos+incr*(event->code/120);
+    if(p<range[0]) p=range[0];
+    if(p>range[1]) p=range[1];
+    if(pos!=p){
+      setValue(p);
+      if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+      }
+    return 1;
     }
-  return 1;
+  return 0;
   }
 
 
