@@ -3,7 +3,7 @@
 *                           R e g i s t r y   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -44,19 +44,19 @@
   - The FOX settings tree stores configuration data for FOX-based applications; it
     is organized as follows:
 
-    SettingsRoot/foxrc                  The "foxrc" file stores common configuration
+    SettingsRoot/fox.rc                 The "foxrc" file stores common configuration
                                         settings for all FOX-based applications,
                                         such as colors and file bindings.
 
-    SettingsRoot/Vendor/Vendorrc        The Vendorrc file is common to all applications
+    SettingsRoot/Vendor/Vendor.rc       The Vendorrc file is common to all applications
                                         from a particular organization, so that common
                                         configurable attributes may be given consistent
                                         values easily.
 
-    SettingsRoot/Vendor/Applicationrc   The Applicationrc file stores configuration data
+    SettingsRoot/Vendor/Application.rc  The Applicationrc file stores configuration data
                                         unique to a specific application only.
 
-    SettingsRoot/Applicationrc          If no Vendor name is specified, the Applicationrc
+    SettingsRoot/Application.rc         If no Vendor name is specified, the Applicationrc
                                         file is located at the toplevel of the SettingsRoot.
 
   - A System-Wide SettingsRoot may be located in a read-only, system adminstrator designated
@@ -158,6 +158,9 @@
                         defaults to "/etc/xdg".
 */
 
+#define TOPIC_CONSTRUCT 1000
+#define TOPIC_DETAIL    1001
+
 #define MAXNAME   200
 #define MAXVALUE  2000
 
@@ -165,7 +168,7 @@
 #if defined(WIN32)
 #define FOXRC           "fox.ini"
 #define SYSTEMDIRS      "C:\\Program Files;C:\\Windows"
-#define USERDIR         "%USERPROFILE%\\fox"
+#define USERDIR         "%USERPROFILE%\\.config"
 #define FILEEXT         ".ini"
 #else
 #define FOXRC           "fox.rc"
@@ -191,6 +194,7 @@ const FXchar FXRegistry::foxrc[]=FOXRC;
 
 // Make registry object
 FXRegistry::FXRegistry(const FXString& akey,const FXString& vkey):applicationkey(akey),vendorkey(vkey),systemdirs(SYSTEMDIRS),userdir(USERDIR){
+  FXTRACE((TOPIC_CONSTRUCT,"FXRegistry::FXRegistry\n"));
 #if defined(WIN32)
   ascii=false;
 #else
@@ -206,7 +210,7 @@ FXbool FXRegistry::readFromRegistry(FXptr hroot,FXbool mrk){
   HKEY hsoftware;
   FXbool ok=false;
 
-  FXTRACE((100,"FXRegistry::readFromRegistry(%p,%d)\n",hroot,mrk));
+  FXTRACE((TOPIC_DETAIL,"FXRegistry::readFromRegistry(%p,%d)\n",hroot,mrk));
 
   // Open Software registry section
   if(RegOpenKeyExA((HKEY)hroot,"Software",0,KEY_READ,&hsoftware)==ERROR_SUCCESS){
@@ -300,7 +304,7 @@ FXbool FXRegistry::readFromRegistryGroup(const FXString& group,FXptr hbase,FXboo
 FXbool FXRegistry::writeToRegistry(FXptr hroot){
   FXbool ok=false;
 
-  FXTRACE((100,"FXRegistry::writeToRegistry(%p)\n",hroot));
+  FXTRACE((TOPIC_DETAIL,"FXRegistry::writeToRegistry(%p)\n",hroot));
 
   // Have application key
   if(!applicationkey.empty()){
@@ -419,6 +423,8 @@ FXbool FXRegistry::read(){
     // Read system-wide settings from systemdirs
     if(!systemdirs.empty()){
 
+      FXTRACE((TOPIC_DETAIL,"FXRegistry::read: systemdirs=%s\n",systemdirs.text()));
+
       // Find common settings
       path=FXPath::search(systemdirs,FOXRC);
       if(!path.empty()){
@@ -458,6 +464,8 @@ FXbool FXRegistry::read(){
     // Read per-user settings from userdir
     if(!userdir.empty()){
 
+      FXTRACE((TOPIC_DETAIL,"FXRegistry::read: userdir=%s\n",userdir.text()));
+
       // Path to settings data
       path=FXPath::absolute(FXPath::expand(userdir));
 
@@ -500,6 +508,8 @@ FXbool FXRegistry::write(){
       // Write per-user settings to userdir
       if(!userdir.empty()){
 
+      FXTRACE((TOPIC_DETAIL,"FXRegistry::write: userdir=%s\n",userdir.text()));
+
         // Have application key
         if(!applicationkey.empty()){
 
@@ -548,6 +558,7 @@ FXbool FXRegistry::write(){
 
 // Destructor
 FXRegistry::~FXRegistry(){
+  FXTRACE((TOPIC_CONSTRUCT,"FXRegistry::~FXRegistry\n"));
   }
 
 }
