@@ -3,7 +3,7 @@
 *                                T i m e   S t u f f                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2019,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2019,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -28,12 +28,12 @@
 #include "FXString.h"
 #include "FXSystem.h"
 
-
 /*
   Notes:
   - Handy functions for manipulating calendar time.
 */
 
+#define TOPIC_DEBUG     1002
 
 using namespace FX;
 
@@ -56,6 +56,10 @@ const FXchar FXSystem::defaultTimeFormat[]="%m/%d/%Y %H:%M:%S";
 const FXchar FXSystem::isoTimeFormat[]="%FT%T%z";
 
 
+// Accurate time format (yyyy-mm-dd hh:mm:ss.ssssss) formatting string
+const FXchar FXSystem::mainTimeFormat[]="%Y-%m-%d %H:%M:%S.%fu";
+
+
 // Cumulative days of the year, for non-leap-years and leap-years
 static const FXint days_of_year[2][13]={
   {0,31,59,90,120,151,181,212,243,273,304,334,365},
@@ -435,12 +439,12 @@ FXTime FXSystem::daylightSavingsActive(FXTime utc){
   struct tm tmresult;
   time_t tmp=(time_t)(utc/seconds);
   struct tm* ptm=localtime_r(&tmp,&tmresult);
-  FXTRACE((300,"FXSystem::daylightSavingsActive(%lld) = %d\n",utc,ptm && ptm->tm_isdst!=0));
+  FXTRACE((TOPIC_DEBUG,"FXSystem::daylightSavingsActive(%lld) = %d\n",utc,ptm && ptm->tm_isdst!=0));
   return ptm && ptm->tm_isdst!=0;
 #else
   time_t tmp=(time_t)(utc/seconds);
   struct tm* ptm=localtime(&tmp);
-  FXTRACE((300,"FXSystem::daylightSavingsActive(%lld) = %d\n",utc,ptm && ptm->tm_isdst!=0));
+  FXTRACE((TOPIC_DEBUG,"FXSystem::daylightSavingsActive(%lld) = %d\n",utc,ptm && ptm->tm_isdst!=0));
   return ptm && ptm->tm_isdst!=0;
 #endif
   }
