@@ -3,7 +3,7 @@
 *                         T o o l   T i p   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -54,6 +54,10 @@
   - Text length dependent tooltip display by leonard@hipgraphics.com.
 */
 
+#define TOPIC_CONSTRUCT 1000
+#define TOPIC_DETAIL    1001
+#define TOPIC_DEBUG     1002
+
 #define HSPACE  4
 #define VSPACE  2
 
@@ -215,7 +219,7 @@ void FXToolTip::place(FXint x,FXint y){
   // Get monitor info if we have this API
   monitor=MonitorFromRect(&rect,MONITOR_DEFAULTTOPRIMARY);
   if(monitor){
-    memset(&minfo,0,sizeof(minfo));
+    clearElms(&minfo,1);
     minfo.cbSize=sizeof(minfo);
     GetMonitorInfo(monitor,&minfo);
     rx=minfo.rcWork.left;
@@ -284,7 +288,7 @@ long FXToolTip::onUpdate(FXObject* sender,FXSelector sel,void* ptr){
 
 // Pop the tool tip now
 long FXToolTip::onTipShow(FXObject*,FXSelector,void*){
-  FXTRACE((250,"%s::onTipShow %p\n",getClassName(),this));
+  FXTRACE((TOPIC_DEBUG,"%s::onTipShow %p\n",getClassName(),this));
   if(!label.empty()){
     autoplace();
     show();
@@ -302,7 +306,7 @@ long FXToolTip::onTipShow(FXObject*,FXSelector,void*){
 
 // Tip should hide now
 long FXToolTip::onTipHide(FXObject*,FXSelector,void*){
-  FXTRACE((250,"%s::onTipHide %p\n",getClassName(),this));
+  FXTRACE((TOPIC_DEBUG,"%s::onTipHide %p\n",getClassName(),this));
   hide();
   return 1;
   }
