@@ -3,7 +3,7 @@
 *                          T r e e L i s t   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -46,7 +46,6 @@
 #include "FXScrollBar.h"
 #include "FXTreeList.h"
 
-
 /*
   Notes:
   - Tooltip should pop up exactly on top of current item.
@@ -71,7 +70,6 @@
 #define HALFBOX_SIZE        4   // Half box size
 #define BOX_FUDGE           3   // Fudge border around box
 
-
 #define SELECT_MASK         (TREELIST_SINGLESELECT|TREELIST_BROWSESELECT)
 #define TREELIST_MASK       (SELECT_MASK|TREELIST_AUTOSELECT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_ROOT_BOXES)
 
@@ -82,7 +80,6 @@ using namespace FX;
 
 namespace FX {
 
-
 // Object implementation
 FXIMPLEMENT(FXTreeItem,FXObject,nullptr,0)
 
@@ -2609,6 +2606,18 @@ FXuint FXTreeList::getListStyle() const {
   }
 
 
+// Change selection mode
+void FXTreeList::setSelectMode(FXuint mode){
+  options=(options&~SELECT_MASK) | (mode&SELECT_MASK);
+  }
+
+
+// Return current selection mode
+FXuint FXTreeList::getSelectMode() const {
+  return (options&SELECT_MASK);
+  }
+
+
 // Save data
 void FXTreeList::save(FXStream& store) const {
   FXScrollArea::save(store);
