@@ -3,7 +3,7 @@
 *                          P P M   I n p u t / O u t p u t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2003,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -29,8 +29,6 @@
 #include "FXElement.h"
 #include "FXStream.h"
 
-
-
 /*
   Notes:
   - Definitely a 'no-frills' format.
@@ -38,6 +36,8 @@
   - No support for values greater than 255.
 */
 
+#define TOPIC_DETAIL 1019
+
 using namespace FX;
 
 /*******************************************************************************/
@@ -126,7 +126,7 @@ FXbool fxloadPPM(FXStream& store,FXColor*& data,FXint& width,FXint& height){
           if(maxvalue<=0 || maxvalue>=256) return false;
           }
 
-        FXTRACE((100,"fxloadPPM: width=%d height=%d type=%c \n",width,height,format));
+        FXTRACE((TOPIC_DETAIL,"fxloadPPM: width=%d height=%d type=%c \n",width,height,format));
 
         // Allocate buffer
         if(callocElms(data,npixels)){
