@@ -3,7 +3,7 @@
 *      S t r i n g   t o   U n s i g n e d   L o n g   C o n v e r s i o n      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -25,7 +25,6 @@
 #include "fxascii.h"
 #include "FXString.h"
 
-
 /*
   Notes:
   - Thread-safe conversion of strings to unsigned long and int, with extra parameter
@@ -49,21 +48,18 @@ extern FXAPI FXuint __strtoul(const FXchar* beg,const FXchar** end=nullptr,FXint
 
 
 // Convert string to unsigned long
-FXulong __strtoull(const FXchar *beg,const FXchar** end,FXint base,FXbool* ok){
-  const FXchar *s=beg;
-  FXulong cutoff=ULLONG_MAX;
+FXulong __strtoull(const FXchar *s,const FXchar** e,FXint base,FXbool* ok){
   FXulong value=0;
-  FXint cutlim;
-  FXint digits=0;
-  FXint neg=0;
-  FXint ovf=0;
+  FXulong prior=0;
+  FXulong ovf=0;
+  FXint neg;
   FXint v;
 
   // Assume the worst
   if(ok) *ok=false;
 
   // No characters consumed
-  if(end) *end=s;
+  if(e) *e=s;
 
   // Keep it reasonable
   if(base<=36){
@@ -74,49 +70,52 @@ FXulong __strtoull(const FXchar *beg,const FXchar** end,FXint base,FXbool* ok){
       }
 
     // Handle sign
-    if(*s=='-'){
-      neg=1;
-      s++;
-      }
-    else if(*s=='+'){
-      s++;
+    if((neg=(s[0]=='-')) || (s[0]=='+')){
+      ++s;
       }
 
-    // Hex, binary, or octal start with 0x, 0b, or plain 0
-    if(s[0]=='0'){
-      if((base<=1 || base==16) && ((s[1]|0x20)=='x')){ base=16; s+=2; }
-      else if((base<=1 || base==2) && ((s[1]|0x20)=='b')){ base=2; s+=2; }
-      else if(base<=1){ base=8; }
-      }
-
-    // Default to decimal base
-    else if(base<=1){
-      base=10;
-      }
-
-    // Overflow check values
-    cutlim=cutoff%base;
-    cutoff=cutoff/base;
-
-    // Scan digits and aggregate number
-    while(0<=(v=Ascii::digitValue(*s)) && v<base){
-      if(!ovf){
-        if(value>cutoff || (value==cutoff && v>cutlim)) ovf=1;
-        value=value*base+v;
+    // Check for '0x...', '0b...', or '00...'
+    if(s[0]=='0' && base!=10){
+      if((s[1]|0x20)=='x'){
+        if(__likely(base==16 || !base)){ base=16; s+=2; }
         }
-      digits++;
-      s++;
-      }
-
-    // At least one digit was found
-    if(0<digits){
-      if(end) *end=s;
-      if(ovf){
-        value=ULLONG_MAX;
+      else if((s[1]|0x20)=='b'){
+        if(__likely(base==2 || !base)){ base=2; s+=2; }
         }
       else{
-        if(neg) value=-(FXlong)value;
+        base=8;
+        }
+      }
+
+    // Base=10 if not already set
+    if(!base) base=10;
+
+    // Scan digits and aggregate number
+    v=Ascii::digitValue(*s);
+    if(0<=v && v<base){
+
+      // Parse digits
+      do{
+        prior=value;
+        value*=base;
+        ovf|=((FXlong)(value-prior))>>63; // Check overflow, branch-free
+        value+=v;
+        v=Ascii::digitValue(*++s);
+        }
+      while(0<=v && v<base);
+
+      // Update end of number
+      if(e) *e=s;
+
+      // Success
+      if(__likely(!ovf)){
         if(ok) *ok=true;
+        if(neg) value=-(FXlong)value;
+        }
+
+      // Overflow
+      else{
+        value=ULLONG_MAX;
         }
       }
     }
@@ -125,8 +124,8 @@ FXulong __strtoull(const FXchar *beg,const FXchar** end,FXint base,FXbool* ok){
 
 
 // Convert string to unsigned int
-FXuint __strtoul(const FXchar* beg,const FXchar** end,FXint base,FXbool* ok){
-  FXulong value=__strtoull(beg,end,base,ok);
+FXuint __strtoul(const FXchar* s,const FXchar** e,FXint base,FXbool* ok){
+  FXulong value=__strtoull(s,e,base,ok);
   if(__unlikely(value>UINT_MAX)){
     if(ok) *ok=false;
     return UINT_MAX;
