@@ -3,7 +3,7 @@
 *                          U t i l i t y   F u n c t i o n s                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -31,7 +31,6 @@
 #include "FXString.h"
 #include "FXElement.h"
 
-
 /*
   Notes:
   - Handy global utility functions.
@@ -49,7 +48,6 @@ using namespace FX;
 
 namespace FX {
 
-
 // Furnish our own versions
 extern FXAPI FXuint __strtoul(const FXchar *beg,const FXchar** end=nullptr,FXint base=0,FXbool* ok=nullptr);
 
@@ -299,33 +297,42 @@ void setTraceLevel(FXuint level,FXbool flag){
 // <topic>       : <digit> [ <digits> ]*
 //
 FXbool setTraceTopics(const FXchar* topics,FXbool flag){
-  if(__likely(topics)){
-    FXuint f,t;
-    while((*topics==':') || ('0'<=*topics && *topics<='9')){
-      f=0;
-      while('0'<=*topics && *topics<='9'){
-        f=f*10+*topics++-'0';
-        }
-      f=FXMIN(f,ARRAYNUMBER(fxTopicArray)-1);
-      t=f;
-      if(*topics==':'){
-        topics++;
-        t=ARRAYNUMBER(fxTopicArray)-1;
-        if('0'<=*topics && *topics<='9'){
-          t=0;
-          while('0'<=*topics && *topics<='9'){
-            t=t*10+*topics++-'0';
+  if(topics){
+    if((*topics==':') || ('0'<=*topics && *topics<='9')){
+      FXuint f,t;
+      do{
+        f=0;
+        while('0'<=*topics && *topics<='9'){
+          f=f*10+*topics++-'0';
+          }
+        if(ARRAYNUMBER(fxTopicArray)<=f){
+          f=ARRAYNUMBER(fxTopicArray)-1;
+          }
+        t=f;
+        if(*topics==':'){
+          topics++;
+          t=ARRAYNUMBER(fxTopicArray)-1;
+          if('0'<=*topics && *topics<='9'){
+            t=0;
+            while('0'<=*topics && *topics<='9'){
+              t=t*10+*topics++-'0';
+              }
+            if(ARRAYNUMBER(fxTopicArray)<=t){
+              t=ARRAYNUMBER(fxTopicArray)-1;
+              }
             }
-          t=FXMIN(t,ARRAYNUMBER(fxTopicArray)-1);
-          if(f>t) swap(f,t);
+          if(f<t){
+            fillElms(&fxTopicArray[f],flag,t-f);
+            }
+          }
+        fxTopicArray[t]=flag;
+        if(*topics==','){
+          topics++;
           }
-        fillElms(&fxTopicArray[f],flag,t-f);
         }
-      fxTopicArray[t]=flag;
-      if(*topics!=',') break;
-      topics++;
+      while((*topics==':') || ('0'<=*topics && *topics<='9'));
+      return (*topics=='\0');
       }
-    return true;
     }
   return false;
   }
@@ -369,6 +376,60 @@ void fxtrace(FXuint level,const FXchar* format,...){
 
 /*******************************************************************************/
 
+// Search substring needle in string haystack
+FXchar* fxstrstr(const FXchar *haystack,const FXchar *needle){
+  FXchar n0,n1,h0,h1;
+  const FXchar *s;
+  const FXchar *p;
+  n0=*needle++;
+  if(__likely(n0)){
+    while((h0=*haystack++)!=0){
+      if(h0!=n0) continue;
+      p=haystack;
+      s=needle;
+      while((n1=*s++)!=0){
+        h1=*p++;
+        if(h1!=n1) goto next;
+        }
+      haystack--;
+      return const_cast<FXchar*>(haystack);
+next: ;
+      }
+    return nullptr;
+    }
+  return const_cast<FXchar*>(haystack);
+  }
+
+
+// Search substring needle in string haystack, ignoring case
+FXchar* fxstrcasestr(const FXchar *haystack,const FXchar *needle){
+  FXchar n0,n1,h0,h1;
+  const FXchar *s;
+  const FXchar *p;
+  n0=*needle++;
+  if(__likely(n0)){
+    n0=Ascii::toLower(n0);
+    while((h0=*haystack++)!=0){
+      h0=Ascii::toLower(h0);
+      if(h0!=n0) continue;
+      p=haystack;
+      s=needle;
+      while((n1=*s++)!=0){
+        h1=*p++;
+        n1=Ascii::toLower(n1);
+        h1=Ascii::toLower(h1);
+        if(h1!=n1) goto next;
+        }
+      haystack--;
+      return const_cast<FXchar*>(haystack);
+next: ;
+      }
+    return nullptr;
+    }
+  return const_cast<FXchar*>(haystack);
+  }
+
+
 // Safe string copy
 FXival fxstrlcpy(FXchar* dst,const FXchar* src,FXival len){
   const FXchar* s=src;
