@@ -3,7 +3,7 @@
 *                             Half Float Support Test                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2008,2023 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2008,2025 by Jeroen van der Zijp.   All Rights Reserved.        *
 ********************************************************************************/
 #include "fx.h"
 
@@ -44,6 +44,9 @@ int main(int argc,char* argv[]){
   FXint i;
   CNV c;
 
+  FXUNUSED(argc);
+  FXUNUSED(argv);
+
   // Fill initial half data
   for(i=0; i<65536; ++i){ *((FXushort*)&initial[i])=i; }
 
